.. _index:

PyScanFCS documentation
=======================

.. image:: _static/PyScanFCS_logo_dark.png

Welcome to the documentation of PyScanFCS (version |release|), a data analysis
software for perpendicular line scanning fluorescence correlation spectroscopy.


.. toctree::
   :maxdepth: 1
   :caption: Contents:


   sec_about
   sec_gallery
   sec_getting_started
   sec_contribute
   sec_changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
